@@ -1,13 +1,13 @@
+import http.server
 import socket
 import threading
-import warnings
-import http.server
-import urllib.parse
 import time
+import urllib.parse
+import warnings
 
 import requests
 import tldextract
-from selenium.common.exceptions import NoSuchWindowException, WebDriverException
+from selenium.common.exceptions import NoSuchWindowException
 
 FIND_WINDOW_HANDLE_WARNING = (
     "Created window handle could not be found reliably. Using less reliable "
@@ -144,32 +144,26 @@ class RequestsSessionMixin(object):
         super(RequestsSessionMixin, self).__init__(*args, **kwargs)
         self.requests_session = requests.Session()
 
+        # Use double underscore to prevent name clashes with all subclasses
+        self.__proxy_host = proxy_host
         self.__has_webdriver_request_headers = False
-        self.__is_phantomjs = self.name == "phantomjs"
-        self.__is_phantomjs_211 = self.__is_phantomjs and self.capabilities["version"] == "2.1.1"
-        self._proxy_host = proxy_host
 
-    # Workaround for PhantomJS bug: https://github.com/ariya/phantomjs/issues/14047
     def add_cookie(self, cookie_dict):
-        try:
-            super(RequestsSessionMixin, self).add_cookie(cookie_dict)
-        except WebDriverException as exception:
-            if not (self.__is_phantomjs_211 and exception.msg == "Unable to set Cookie"):
-                raise
+        super(RequestsSessionMixin, self).add_cookie(cookie_dict)
 
     def request(self, method, url, **kwargs):
         if not self.__has_webdriver_request_headers:
             # Workaround for Chrome bug: https://bugs.chromium.org/p/chromedriver/issues/detail?id=1077
             if self.name == "chrome":
                 window_handles_before = len(self.window_handles)
-                self.requests_session.headers = get_webdriver_request_headers(self, proxy_host=self._proxy_host)
+                self.requests_session.headers = get_webdriver_request_headers(self, proxy_host=self.__proxy_host)
 
                 # Wait until the newly opened window handle is closed again, to prevent switching to it just as it is
                 # about to be closed
                 while len(self.window_handles) > window_handles_before:
                     time.sleep(0.01)
             else:
-                self.requests_session.headers = get_webdriver_request_headers(self, proxy_host=self._proxy_host)
+                self.requests_session.headers = get_webdriver_request_headers(self, proxy_host=self.__proxy_host)
 
             self.__has_webdriver_request_headers = True
 
@@ -240,7 +234,3 @@ class RequestsSessionMixin(object):
             self.switch_to.window(original_window_handle)
 
         return response
-
-
-# backwards-compatibility
-RequestMixin = RequestsSessionMixin
